@@ -148,7 +148,7 @@ public:
             return -1;
         } else {
             uint pos = 1;
-            foreach ( Parser::TokenType type, list ) {
+            for( Parser::TokenType type : list ) {
                 if ( skipWhitespace && m_stream.at( m_pos - pos).kind == Parser::Token_WHITESPACE ) {
                     ++pos;
                 }
@@ -361,7 +361,7 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
             if ( m_memberAccessOperation == InterfaceChoose ) {
                 ifDebug(qCDebug(COMPLETION) << "in implementation list";)
                 m_memberAccessOperation = InterfaceChoose;
-                foreach ( qint64 pos, identifierPositions ) {
+                for( qint64 pos : identifierPositions ) {
                     forbidIdentifier(lastToken.stringAt(pos));
                 }
             } else {
@@ -911,7 +911,7 @@ void CodeCompletionContext::evaluateExpression(TokenAccess& lastToken)
             LOCKDUCHAIN;
             ifDebug(qCDebug(COMPLETION) << "expression type: " << m_expressionResult.type()->toString();)
         } else {
-            ifDebug(qCDebug(COMPLETION) << QString("expression could not be evaluated"));
+            ifDebug(qCDebug(COMPLETION) << QStringLiteral("expression could not be evaluated"));
             if ( m_memberAccessOperation == FunctionCallAccess ) {
                 ifDebug(qCDebug(COMPLETION) << "function not found";)
                 return;
@@ -932,7 +932,7 @@ void CodeCompletionContext::evaluateExpression(TokenAccess& lastToken)
         if ( lastToken.type() == Parser::Token_COMMA ) {
             removeOtherArguments(lastToken);
             if ( lastToken.type() == Parser::Token_INVALID ) {
-                ifDebug(qCDebug(COMPLETION) << QString("Could not find start position for parent function-call. Aborting.");)
+                ifDebug(qCDebug(COMPLETION) << QStringLiteral("Could not find start position for parent function-call. Aborting.");)
                 m_valid = false;
                 return;
             }
@@ -944,7 +944,7 @@ void CodeCompletionContext::evaluateExpression(TokenAccess& lastToken)
             return;
         }
 
-        ifDebug(qCDebug(COMPLETION) << QString("Recursive function-call: creating parent context"));
+        ifDebug(qCDebug(COMPLETION) << QStringLiteral("Recursive function-call: creating parent context"));
         m_parentContext = new CodeCompletionContext(m_duContext, m_position, lastToken, m_depth + 1);
 
         if (!m_parentContext->isValid()) {
@@ -1042,13 +1042,13 @@ QList<DUContext*> CodeCompletionContext::memberAccessContainers() const
     } else {
         types << expressionTarget;
     }
-    foreach (const AbstractType::Ptr &type, types) {
+    for(const AbstractType::Ptr &type : types) {
         const IdentifiedType* idType = dynamic_cast<const IdentifiedType*>(type.data());
-        Declaration* declaration = 0;
+        Declaration *declaration = nullptr;
         if (idType) {
             declaration = idType->declaration(m_duContext->topContext());
         }
-        DUContext* ctx = 0;
+        DUContext *ctx = nullptr;
         if (declaration) {
             ctx = declaration->logicalInternalContext(m_duContext->topContext());
         }
@@ -1112,12 +1112,12 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& ab
         QList<Path> addedPaths;
         bool addedParentDir = false;
         const QUrl baseUrl = base.toUrl();
-        foreach ( ProjectBaseItem* item, ICore::self()->projectController()->projectModel()->itemsForPath(IndexedString(base.toUrl())) ) {
+        for(ProjectBaseItem *item : ICore::self()->projectController()->projectModel()->itemsForPath(IndexedString(base.toUrl())) ) {
             if ( abort || !item->folder() ) {
                 break;
             }
             auto folder = item->folder();
-            foreach ( ProjectFileItem* subFile, folder->fileList() ) {
+            for( ProjectFileItem* subFile : folder->fileList() ) {
                 if ( abort ) {
                     break;
                 }
@@ -1135,7 +1135,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& ab
                 }
                 items << CompletionTreeItemPointer(new IncludeFileItem(item));
             }
-            foreach ( ProjectFolderItem* subFolder, folder->folderList() ) {
+            for( ProjectFolderItem* subFolder : folder->folderList() ) {
                 if ( abort ) {
                     break;
                 }
@@ -1249,7 +1249,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& ab
                     //TODO: use the token stream here as well
                     //TODO: always add __construct, __destruct and maby other magic functions
                     // get all visible declarations and add inherited to the completion items
-                    foreach(DeclarationDepthPair decl, ctx->allDeclarations(ctx->range().end, m_duContext->topContext(), false)) {
+                    for(DeclarationDepthPair decl : ctx->allDeclarations(ctx->range().end, m_duContext->topContext(), false)) {
                         ClassMemberDeclaration *member = dynamic_cast<ClassMemberDeclaration*>(decl.first);
                         ClassFunctionDeclaration *classFunc = dynamic_cast<ClassFunctionDeclaration*>(decl.first);
                         if (member) {
@@ -1318,11 +1318,11 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& ab
             }
         }
     } else if (m_memberAccessOperation == BackslashAccess || m_memberAccessOperation == NamespaceChoose) {
-        DUContext* ctx = 0;
+        DUContext *ctx = nullptr;
         if (m_namespace.isEmpty()) {
             ctx = m_duContext->topContext();
         } else {
-            foreach(Declaration* dec, m_duContext->topContext()->findDeclarations(m_namespace)) {
+            for(Declaration* dec : m_duContext->topContext()->findDeclarations(m_namespace)) {
                 if (dec->kind() == Declaration::Namespace) {
                     ctx = dec->internalContext();
                     break;
@@ -1333,7 +1333,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& ab
             qCDebug(COMPLETION) << "could not find namespace:" << m_namespace.toString();
             return items;
         }
-        foreach(Declaration* dec, ctx->localDeclarations()) {
+        for(Declaration* dec : ctx->localDeclarations()) {
             if (!isValidCompletionItem(dec)) {
                 continue;
             } else {
@@ -1350,18 +1350,18 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& ab
         qCDebug(COMPLETION) << "containers: " << containers.count();
         if (!containers.isEmpty()) {
             // get the parent class when we are inside a method declaration
-            ClassDeclaration* currentClass = 0;
+            ClassDeclaration *currentClass = nullptr;
             if (m_duContext->owner() && m_duContext->owner()->isFunctionDeclaration() &&
                     m_duContext->parentContext() && m_duContext->parentContext()->owner()) {
                 currentClass = dynamic_cast<ClassDeclaration*>(m_duContext->parentContext()->owner());
             }
 
-            foreach(DUContext* ctx, containers) {
+            for(DUContext* ctx : containers) {
                 ClassDeclaration* accessedClass = dynamic_cast<ClassDeclaration*>(ctx->owner());
                 if (abort)
                     return items;
 
-                foreach(DeclarationDepthPair decl, ctx->allDeclarations(
+                for(DeclarationDepthPair decl : ctx->allDeclarations(
                                                             ctx->range().end, m_duContext->topContext(), false))
                 {
                     //If we have StaticMemberAccess, which means A::Bla, show only static members,
@@ -1458,24 +1458,24 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& ab
                     );
         }
 
-        foreach(QSet<IndexedString> urlSets, completionFiles()) {
-            foreach(const IndexedString &url, urlSets) {
+        for(QSet<IndexedString> urlSets : completionFiles()) {
+            for(const IndexedString &url : urlSets) {
                 if (url == m_duContext->url()) {
                     continue;
                 }
                 uint count = 0;
-                const CodeModelItem* foundItems = 0;
+                const CodeModelItem *foundItems = nullptr;
                 CodeModel::self().items(url, count, foundItems);
                 for (uint i = 0; i < count; ++i) {
                     CodeModelItem::Kind k = foundItems[i].kind;
                     if (((k & CodeModelItem::Function) || (k & CodeModelItem::Variable)) && !(k & CodeModelItem::ClassMember)) {
-                        foreach(const ParsingEnvironmentFilePointer &env, DUChain::self()->allEnvironmentFiles(url)) {
+                        for(const ParsingEnvironmentFilePointer &env : DUChain::self()->allEnvironmentFiles(url)) {
                             if (env->language() != phpLangString) continue;
                             TopDUContext* top = env->topContext();
                             if(!top) continue;
                             if (m_duContext->imports(top)) continue;
                             QList<Declaration*> decls = top->findDeclarations(foundItems[i].id);
-                            foreach(Declaration* decl, decls) {
+                            for(Declaration* decl : decls) {
                                 if (abort) return items;
                                 // we don't want to have class methods/properties, just normal functions
                                 // and other global stuff
@@ -1501,10 +1501,10 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& ab
             }
         }
 
-        foreach(QSet<IndexedString> urlSets, completionFiles()) {
-            foreach(const IndexedString &url, urlSets) {
+        for(QSet<IndexedString> urlSets : completionFiles()) {
+            for(const IndexedString &url : urlSets) {
                 uint count = 0;
-                const CompletionCodeModelItem* foundItems = 0;
+                const CompletionCodeModelItem *foundItems = nullptr;
                 CompletionCodeModel::self().items(url, count, foundItems);
                 for (uint i = 0; i < count; ++i) {
                     if (abort) return items;
@@ -1513,7 +1513,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& ab
                     }
                     auto files = DUChain::self()->allEnvironmentFiles(url);
                     items.reserve(files.size());
-                    foreach(const ParsingEnvironmentFilePointer &env, files) {
+                    for(const ParsingEnvironmentFilePointer &env : files) {
                         Q_ASSERT(env->language() == phpLangString);
                         items << CompletionTreeItemPointer ( new CodeModelCompletionItem(env, foundItems[i]));
                     }
@@ -1541,15 +1541,15 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& ab
                     if ( !decl->isFunctionDeclaration() ) {
                         if ( ClassDeclaration* classDec = dynamic_cast<ClassDeclaration*>(decl) ) {
                             // search for ctor
-                            decl = 0;
-                            foreach ( Declaration* dec, classDec->internalContext()->findDeclarations(Identifier("__construct")) ) {
+                            decl = nullptr;
+                            for(Declaration *dec : classDec->internalContext()->findDeclarations(Identifier("__construct")) ) {
                                 if ( dec->isFunctionDeclaration() ) {
                                     decl = dec;
                                     break;
                                 }
                             }
                             if ( !decl ) {
-                                foreach ( Declaration* dec, classDec->internalContext()->findDeclarations(classDec->identifier()) ) {
+                                for(Declaration *dec : classDec->internalContext()->findDeclarations(classDec->identifier()) ) {
                                     if ( dec->isFunctionDeclaration() ) {
                                         decl = dec;
                                         break;
@@ -1757,7 +1757,7 @@ QList<QSet<IndexedString> > CodeCompletionContext::completionFiles()
     if (ICore::self()) {
         auto projects = ICore::self()->projectController()->projects();
         ret.reserve(projects.size());
-        foreach(IProject* project, projects) {
+        for(IProject *project : projects) {
             ret << project->fileSet();
         }
     }
