@@ -9,7 +9,7 @@
 #include "associationwidget.h"
 #include "debug_utils.h"
 #include "model_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umlscene.h"
 #include "umlwidget.h"
 
