@@ -9,20 +9,19 @@
 
 #include "debug_utils.h"
 #include "umldoc.h"
-#include "uml.h"
-#include "classifier.h"
-#include "enum.h"
-#include "classifierlistitem.h"
+#include "umlapp.h"
+#include "umlclassifier.h"
+#include "umlenum.h"
+#include "umlclassifierlistitem.h"
 #include "umlclassifierlistitemlist.h"
 #include "umltemplatelist.h"
-#include "folder.h"
-#include "association.h"
-#include "attribute.h"
-#include "operation.h"
-#include "template.h"
+#include "umlfolder.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umloperation.h"
+#include "umltemplate.h"
 
 #include <KLocalizedString>
-#include <KMessageBox>
 
 #include <QFile>
 #include <QRegularExpression>
@@ -416,7 +415,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     }
 
     // Generate public operations.
-    UMLOperationList opl(c->getOpList());
+    UMLOperationList opl(c->getOperationsList());
     UMLOperationList oppub;
     for(UMLOperation* op : opl) {
         if (op->visibility() == Uml::Visibility::Public)
@@ -440,7 +439,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
  */
 void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comment)
 {
-    UMLAttributeList atl = op->getParmList();
+    UMLAttributeList atl = op->getParameterList();
     QString rettype = op->getTypeName();
     bool use_procedure = (rettype.isEmpty() || rettype == QStringLiteral("void"));
 
@@ -743,7 +742,7 @@ void AdaWriter::finalizeRun()
                         ada << m_endl;
                 }
             }
-            UMLOperationList opl(c->getOpList());
+            UMLOperationList opl(c->getOperationsList());
             // Generate protected operations.
             UMLOperationList opprot;
             for(UMLOperation* op : opl) {
