@@ -6,19 +6,17 @@
 #include "idlwriter.h"
 
 #include "umldoc.h"
-#include "uml.h"  // only needed for log{Warn,Error}
+#include "umlapp.h"  // only needed for log{Warn,Error}
 #include "debug_utils.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
-#include "enum.h"
-#include "classifierlistitem.h"
+#include "umlenum.h"
+#include "umlclassifierlistitem.h"
 #include "umlclassifierlistitemlist.h"
-#include "package.h"
-#include "association.h"
-#include "attribute.h"
-#include "operation.h"
-
-#include <KMessageBox>
+#include "umlpackage.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umloperation.h"
 
 #include <QFile>
 #include <QRegularExpression>
@@ -375,7 +373,7 @@ void IDLWriter::writeClass(UMLClassifier *c)
     }
 
     // Generate public operations.
-    UMLOperationList opl(c->getOpList());
+    UMLOperationList opl(c->getOperationsList());
     UMLOperationList oppub;
 
     for(UMLOperation* op : opl) {
@@ -431,7 +429,7 @@ void IDLWriter::writeClass(UMLClassifier *c)
  */
 void IDLWriter::writeOperation(UMLOperation *op, QTextStream &idl, bool is_comment)
 {
-    UMLAttributeList atl = op->getParmList();
+    UMLAttributeList atl = op->getParameterList();
     QString rettype = op->getTypeName();
 
     if (rettype.isEmpty())
