@@ -10,14 +10,14 @@
 
 // local includes
 #include "codegen_utils.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
 #include "rubycodegenerator.h"
 #include "rubycodecomment.h"
 #include "rubyclassdeclarationblock.h"
 #include "rubycodeclassfielddeclarationblock.h"
 #include "rubycodeoperation.h"
-#include "uml.h"
+#include "umlapp.h"
 
 DEBUG_REGISTER_DISABLED(RubyClassifierCodeDocument)
 
@@ -354,7 +354,7 @@ void RubyClassifierCodeDocument::updateContent()
     bool hasOperationMethods = false;
     Q_ASSERT(c != nullptr);
     if (c) {
-        UMLOperationList list = c->getOpList();
+        UMLOperationList list = c->getOperationsList();
         hasOperationMethods = ! list.isEmpty();
     }
     CodeGenerationPolicy *pol = UMLApp::app()->commonPolicy();
