@@ -7,11 +7,11 @@
 #include "codegenselectpage.h"
 
 // app includes
-#include "folder.h"
+#include "umlfolder.h"
 #include "umldoc.h"
-#include "uml.h"
-#include "classifier.h"
-#include "entity.h"
+#include "umlapp.h"
+#include "umlclassifier.h"
+#include "umlentity.h"
 
 //kde includes
 #include <KLocalizedString>
@@ -54,12 +54,12 @@ void CodeGenSelectPage::setClassifierList(UMLClassifierList *classList)
     UMLClassifierList cList;
     ui_listSelected->clear();
 
-    if (classList == 0) {
+    if (classList == nullptr) {
         Uml::ProgrammingLanguage::Enum pl = UMLApp::app()->activeLanguage();
         switch (pl) {
             case Uml::ProgrammingLanguage::PostgreSQL:
             case Uml::ProgrammingLanguage::MySQL:
-                foreach (UMLEntity* ent, doc->entities()) {
+                for(UMLEntity* ent : doc->entities()) {
                     cList.append(ent);
                 }
                 break;
@@ -70,7 +70,7 @@ void CodeGenSelectPage::setClassifierList(UMLClassifierList *classList)
         classList = &cList;
     }
 
-    foreach (UMLClassifier* c, cList) {
+    for(UMLClassifier* c : cList) {
         new QListWidgetItem(c->fullyQualifiedName(), ui_listSelected);
     }
 }
@@ -104,7 +104,7 @@ QListWidget* CodeGenSelectPage::getSelectionListWidget()
 void CodeGenSelectPage::selectClass()
 {
     moveSelectedItems(ui_listAvailable, ui_listSelected);
-    emit completeChanged();
+    Q_EMIT completeChanged();
 }
 
 /**
@@ -114,7 +114,7 @@ void CodeGenSelectPage::selectClass()
 void CodeGenSelectPage::deselectClass()
 {
     moveSelectedItems(ui_listSelected, ui_listAvailable);
-    emit completeChanged();
+    Q_EMIT completeChanged();
 }
 
 /**
@@ -127,7 +127,7 @@ void CodeGenSelectPage::deselectClass()
  */
 void CodeGenSelectPage::moveSelectedItems(QListWidget* fromList, QListWidget* toList)
 {
-    foreach (QListWidgetItem* item, fromList->selectedItems()) {
+    for(QListWidgetItem* item : fromList->selectedItems()) {
         QString name = item->text();
         QList<QListWidgetItem*> foundItems = toList->findItems(name, Qt::MatchExactly);
         if (foundItems.isEmpty()) {
