@@ -13,7 +13,7 @@ class CodeTextEdit;
 class UMLObject;
 class UMLWidget;
 
-class KTextEdit;
+class QTextEdit;
 
 class QGridLayout;
 class QGroupBox;
@@ -22,16 +22,16 @@ class DocumentationWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit DocumentationWidget(UMLObject *o, QWidget *parent = 0);
-    explicit DocumentationWidget(UMLWidget *w, QWidget *parent = 0);
-    explicit DocumentationWidget(AssociationWidget *w, QWidget *parent = 0);
+    explicit DocumentationWidget(UMLObject *o, QWidget *parent = nullptr);
+    explicit DocumentationWidget(UMLWidget *w, QWidget *parent = nullptr);
+    explicit DocumentationWidget(AssociationWidget *w, QWidget *parent = nullptr);
     ~DocumentationWidget();
 
     void apply();
 
 protected:
     QGroupBox *m_box;
-    KTextEdit *m_editField;
+    QTextEdit *m_editField;
     CodeTextEdit *m_codeEditField;
     UMLObject *m_object;
     UMLWidget *m_widget;
