@@ -5,26 +5,28 @@
 
 // own header
 #include "umlviewimageexportermodel.h"
+#include "dialog_utils.h"
 
 // application specific includes
 #define DBG_SRC QStringLiteral("UMLViewImageExporterModel")
 #include "debug_utils.h"
 #include "dotgenerator.h"
 #include "model_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
 
 // kde include files
+#include <KIO/CopyJob>
 #include <KIO/Job>
-#include <KJobWidgets>
 #include <KIO/MkdirJob>
+#include <KIO/StatJob>
+#include <KJobWidgets>
 #include <KLocalizedString>
 
 // include files for Qt
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QDir>
 #include <QImage>
 #include <QImageWriter>
@@ -32,13 +34,9 @@
 #include <QPicture>
 #include <QPrinter>
 #include <QRect>
-#include <QRegExp>
 #include <QSvgGenerator>
 #include <QTemporaryFile>
 
-// system includes
-#include <cmath>
-
 DEBUG_REGISTER(UMLViewImageExporterModel)
 
 QStringList *UMLViewImageExporterModel::s_supportedImageTypesList;
@@ -56,7 +54,7 @@ QStringList UMLViewImageExporterModel::supportedImageTypes()
         s_supportedImageTypesList = new QStringList();
         // QT supported formats
         QList<QByteArray> qImageFormats = QImageWriter::supportedImageFormats();
-        Q_FOREACH(const QByteArray& it, qImageFormats) {
+        for(const QByteArray& it : qImageFormats) {
             const QString format = QString::fromLatin1(it.toLower());
             if (!s_supportedImageTypesList->contains(format))
                 *s_supportedImageTypesList << format;
@@ -204,7 +202,7 @@ QStringList UMLViewImageExporterModel::exportViews(const UMLViewList &views, con
     // contains all the error messages returned by exportView calls
     QStringList errors;
 
-    foreach (UMLView *view, views) {
+    for(UMLView *view : views) {
         QUrl url = QUrl::fromLocalFile(directory.path() + QLatin1Char('/') +
                  getDiagramFileName(view->umlScene(), imageType, useFolders));
 
@@ -263,7 +261,11 @@ QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &im
 
     // if the file wasn't local, upload the temp file to the target
     if (!url.isLocalFile()) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        KIO::Job* job = KIO::copy(QUrl::fromLocalFile(tmpFile.fileName()), url);
+#else
         KIO::FileCopyJob *job = KIO::file_copy(QUrl::fromLocalFile(tmpFile.fileName()), url);
+#endif
         KJobWidgets::setWindow(job, UMLApp::app());
         job->exec();
         if (job->error()) {
@@ -283,7 +285,7 @@ QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &im
  */
 QString UMLViewImageExporterModel::getDiagramFileName(UMLScene* scene, const QString &imageType, bool useFolders /* = false */) const
 {
-    if (scene == 0) {
+    if (scene == nullptr) {
         logWarn0("UMLViewImageExporterModel::getDiagramFileName: Scene is null!");
         return QString();
     }
@@ -309,10 +311,10 @@ bool UMLViewImageExporterModel::prepareDirectory(const QUrl &url) const
     directory.setPath(QString());
 
     // creates the directory and any needed parent directories
-    QStringList dirs = url.adjusted(QUrl::RemoveFilename).path().split(QDir::separator(), QString::SkipEmptyParts);
+    QStringList dirs = url.adjusted(QUrl::RemoveFilename).path().split(QDir::separator(), Qt::SkipEmptyParts);
     for (QStringList::ConstIterator it = dirs.constBegin() ; it != dirs.constEnd(); ++it) {
         directory.setPath(directory.path() + QLatin1Char('/') + *it);
-        KIO::StatJob *statJob = KIO::stat(directory, KIO::StatJob::SourceSide, 0);
+        KIO::StatJob *statJob = KIO::stat(directory, KIO::StatJob::SourceSide, KIO::StatDetails(0));
         KJobWidgets::setWindow(statJob, UMLApp::app());
         statJob->exec();
         if (statJob->error()) {
@@ -412,16 +414,17 @@ bool UMLViewImageExporterModel::exportViewToEps(UMLScene* scene, const QString &
         rect = QRectF(0,0, 10, 10);
     }
 
-    QSizeF paperSize(rect.size() * 25.4f / qApp->desktop()->logicalDpiX());
+    QPageSize paperSize(rect.size() * 25.4f / Dialog_Utils::logicalDpiXForWidget(), QPageSize::Millimeter);
 
     QPrinter printer(QPrinter::ScreenResolution);
     printer.setOutputFileName(fileName);
     printer.setOutputFormat(QPrinter::PdfFormat);
     printer.setColorMode(QPrinter::Color);
-    printer.setPaperSize(paperSize, QPrinter::Millimeter);
-    printer.setPageMargins(paperSize.width() * border, paperSize.height() * border, 0, 0, QPrinter::Millimeter);
-    printer.setResolution(qApp->desktop()->logicalDpiX());
-    printer.setOrientation(paperSize.width() < paperSize.height() ? QPrinter::Landscape : QPrinter::Portrait);
+    printer.setPageSize(paperSize);
+    QMarginsF margins(paperSize.size(QPageSize::Millimeter).width() * border, paperSize.size(QPageSize::Millimeter).height() * border, 0, 0);
+    printer.setPageMargins(margins);
+    printer.setResolution(Dialog_Utils::logicalDpiXForWidget());
+    printer.setPageOrientation(paperSize.size(QPageSize::Millimeter).width() < paperSize.size(QPageSize::Millimeter).height() ? QPageLayout::Landscape : QPageLayout::Portrait);
 
     // do not call printer.setup(); because we want no user
     // interaction here
@@ -438,7 +441,7 @@ bool UMLViewImageExporterModel::exportViewToEps(UMLScene* scene, const QString &
     scene->getDiagram(painter, rect);
 
     // next painting will most probably be to a different device (i.e. the screen)
-    scene->forceUpdateWidgetFontMetrics(0);
+    scene->forceUpdateWidgetFontMetrics(nullptr);
 
     return true;
 }
@@ -467,7 +470,7 @@ bool UMLViewImageExporterModel::exportViewToSvg(UMLScene* scene, const QString &
     QSvgGenerator generator;
     generator.setFileName(fileName);
     generator.setSize(rect.toRect().size());
-    generator.setResolution(qApp->desktop()->logicalDpiX());
+    generator.setResolution(Dialog_Utils::logicalDpiXForWidget());
     generator.setViewBox(QRect(0, 0, rect.width(), rect.height()));
     QPainter painter(&generator);
 
@@ -517,8 +520,8 @@ bool UMLViewImageExporterModel::exportViewToPixmap(UMLScene* scene, const QStrin
         rect = QRectF(0,0, 10, 10);
     }
 
-    float scale = !qFuzzyIsNull(m_resolution) ? m_resolution / qApp->desktop()->logicalDpiX()
-                                              : 72.0f / qApp->desktop()->logicalDpiX();
+    float scale = !qFuzzyIsNull(m_resolution) ? m_resolution / Dialog_Utils::logicalDpiXForWidget()
+                                              : 72.0f / Dialog_Utils::logicalDpiXForWidget();
     QSizeF size = rect.size() * scale;
     QPixmap diagram(size.toSize());
     scene->getDiagram(diagram, rect);
