@@ -7,11 +7,11 @@
 #include "artifactwidget.h"
 
 // app includes
-#include "artifact.h"
+#include "umlartifact.h"
 #include "debug_utils.h"
 #include "umlscene.h"
 #include "umlview.h"
-#include "uml.h"  // only needed for log{Warn,Error}
+#include "umlapp.h"  // only needed for log{Warn,Error}
 
 // qt includes
 #include <QXmlStreamWriter>
