@@ -7,10 +7,10 @@
 #include "floatingtextwidget.h"
 
 // local includes
-#include "association.h"
+#include "umlassociation.h"
 #include "associationwidget.h"
 #include "associationpropertiesdialog.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "cmds.h"
 #include "debug_utils.h"
 #include "dialog_utils.h"
@@ -20,9 +20,9 @@
 #include "messagewidget.h"
 #include "model_utils.h"
 #include "object_factory.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "selectoperationdialog.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlview.h"
 
