@@ -7,10 +7,10 @@
 #include "linkwidget.h"
 
 // app includes
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
-#include "operation.h"
-#include "uml.h"
+#include "umloperation.h"
+#include "umlapp.h"
 #include "umlobject.h"
 #include "umlview.h"
 
