@@ -6,16 +6,16 @@
 #include "umlwidget.h"
 
 // local includes
-#include "artifact.h"
+#include "umlartifact.h"
 #include "artifactwidget.h"
 #include "activitywidget.h"
-#include "actor.h"
+#include "umlactor.h"
 #include "actorwidget.h"
 #include "associationwidget.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "classpropertiesdialog.h"
 #include "cmds.h"
-#include "component.h"
+#include "umlcomponent.h"
 #include "componentwidget.h"
 #include "debug_utils.h"
 #include "dialog_utils.h"
@@ -31,20 +31,20 @@
 #include "menus/listpopupmenu.h"
 #include "objectnodewidget.h"
 #include "pinwidget.h"
-#include "port.h"
+#include "umlport.h"
 #include "portwidget.h"
 #include "regionwidget.h"
 #include "signalwidget.h"
 #include "settingsdialog.h"
 #include "statewidget.h"
-#include "stereotype.h"
-#include "uml.h"
+#include "umlstereotype.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umllistview.h"
 #include "umlobject.h"
 #include "umlscene.h"
 #include "umlview.h"
-#include "usecase.h"
+#include "umlusecase.h"
 #include "usecasewidget.h"
 #include "uniqueid.h"
 #include "widget_factory.h"
@@ -52,7 +52,6 @@
 
 // kde includes
 #include <KLocalizedString>
-#include <KMessageBox>
 
 // qt includes
 #include <QApplication>
