@@ -5,11 +5,11 @@
 
 #include "widgetbase.h"
 
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
 #include "dialog_utils.h"
 #include "floatingtextwidget.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umllistview.h"
 #include "umlobject.h"
@@ -595,6 +595,19 @@ void WidgetBase::setChangesShape(bool state)
     m_changesShape = state;
 }
 
+bool WidgetBase::highLighted() const
+{
+    return m_highLighted;
+}
+
+void WidgetBase::setHighLighted(bool state)
+{
+    bool oldState = m_highLighted;
+    m_highLighted = state;
+    if (oldState != state)
+        update();
+}
+
 /**
  * A virtual method for the widget to display a property dialog box.
  * Subclasses should reimplement this appropriately.
