@@ -8,17 +8,29 @@
 
 // app includes
 #include "codegenerationpolicy.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 
+// KDE includes
+#include <KLocalizedString>
+
 // qt includes
 #include <QApplication>
+#include <QTemporaryDir>
 
 #if !defined(QT_GUI_LIB)
 #error umbrello unittests require QT_GUI_LIB to be present
 #endif
 
-#include <QTemporaryDir>
+static QtMessageHandler defaultHandler = nullptr;
+
+void customMessageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
+{
+    if (type == QtWarningMsg && msg.contains(QStringLiteral("The window title does not contain a '[*]' placeholder"))) {
+        return;
+    }
+    defaultHandler(type, context, msg);
+}
 
 TestBase::TestBase(QObject *parent)
   : QObject(parent)
@@ -27,6 +39,12 @@ TestBase::TestBase(QObject *parent)
 
 void TestBase::initTestCase()
 {
+    KLocalizedString::setApplicationDomain("umbrello");
+
+    // hide Qt warning
+    // QWARN  : ... QWidget::setWindowModified: The window title does not contain a '[*]' placeholder
+    defaultHandler = qInstallMessageHandler(customMessageHandler);
+
     QWidget *w = new QWidget;
     UMLApp *app = new UMLApp(w);
     app->setup();
