@@ -7,13 +7,13 @@
 #include "testumlobject.h"
 
 // app include
-#include "attribute.h"
-#include "classifier.h"
-#include "folder.h"
-#include "operation.h"
-#include "package.h"
-#include "stereotype.h"
-#include "uml.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
+#include "umlfolder.h"
+#include "umloperation.h"
+#include "umlpackage.h"
+#include "umlstereotype.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlobject.h"
 
